@@ -224,6 +224,29 @@ export type PostProcessingFlatten =
   | _PostProcessingFlatten
   | DefaultPostProcessing;
 
+interface _PostProcessingRank {
+  operation: 'rank';
+  options?: {
+    metric: string;
+    group_by: string | null;
+  };
+}
+export type PostProcessingRank = _PostProcessingRank | DefaultPostProcessing;
+
+interface _PostProcessingHistogram {
+  operation: 'histogram';
+  options?: {
+    column: string;
+    groupby: string[];
+    bins: number;
+    cumulative?: boolean;
+    normalize?: boolean;
+  };
+}
+export type PostProcessingHistogram =
+  | _PostProcessingHistogram
+  | DefaultPostProcessing;
+
 /**
  * Parameters for chart data postprocessing.
  * See superset/utils/pandas_processing.py.
@@ -241,7 +264,9 @@ export type PostProcessingRule =
   | PostProcessingSort
   | PostProcessingResample
   | PostProcessingRename
-  | PostProcessingFlatten;
+  | PostProcessingFlatten
+  | PostProcessingHistogram
+  | PostProcessingRank;
 
 export function isPostProcessingAggregation(
   rule?: PostProcessingRule,
@@ -308,3 +333,27 @@ export function isPostProcessingResample(
 ): rule is PostProcessingResample {
   return rule?.operation === 'resample';
 }
+
+export function isPostProcessingRename(
+  rule?: PostProcessingRule,
+): rule is PostProcessingRename {
+  return rule?.operation === 'rename';
+}
+
+export function isPostProcessingFlatten(
+  rule?: PostProcessingRule,
+): rule is PostProcessingFlatten {
+  return rule?.operation === 'flatten';
+}
+
+export function isPostProcessingRank(
+  rule?: PostProcessingRule,
+): rule is PostProcessingRank {
+  return rule?.operation === 'rank';
+}
+
+export function isPostProcessingHistogram(
+  rule?: PostProcessingRule,
+): rule is PostProcessingHistogram {
+  return rule?.operation === 'histogram';
+}
