@@ -18,7 +18,7 @@
  */
 /* eslint-disable react/no-array-index-key */
 import PropTypes from 'prop-types';
-import React from 'react';
+import { PureComponent } from 'react';
 import { styled } from '@superset-ui/core';
 import TTestTable, { dataPropType } from './TTestTable';
 
@@ -115,7 +115,7 @@ const StyledDiv = styled.div`
   `}
 `;
 
-class PairedTTest extends React.PureComponent {
+class PairedTTest extends PureComponent {
   render() {
     const { className, metrics, groups, data, alpha, pValPrec, liftValPrec } =
       this.props;
