@@ -40,13 +40,11 @@ const metadata = new ChartMetadata({
     t('Time'),
     t('Trend'),
     t('Stacked'),
-    t('Vertical'),
     t('Percentages'),
     t('Proportional'),
     t('Advanced-Analytics'),
     t('nvd3'),
     t('Legacy'),
-    t('Deprecated'),
   ],
   thumbnail,
   useLegacyApi: true,
