@@ -29,7 +29,7 @@ import {
   getTimeFormatter,
   isDefined,
   NumberFormats,
-  smartDateVerboseFormatter,
+  SMART_DATE_VERBOSE_ID,
   t,
 } from '@superset-ui/core';
 
@@ -82,6 +82,8 @@ const NO_DATA_RENDER_DATA = [
   },
 ];
 
+const smartDateVerboseFormatter = getTimeFormatter(SMART_DATE_VERBOSE_ID);
+
 // Override the noData render function to make a prettier UX
 // Code adapted from https://github.com/novus/nvd3/blob/master/src/utils.js#L653
 nv.utils.noData = function noData(chart, container) {
@@ -656,7 +658,9 @@ function nvd3Vis(element, props) {
     } else if (vizType !== 'bullet') {
       const colorFn = getScale(colorScheme);
       chart.color(
-        d => d.color || colorFn(cleanColorInput(d[colorKey]), sliceId),
+        d =>
+          d.color ||
+          colorFn(cleanColorInput(d[colorKey]), sliceId, colorScheme),
       );
     }
 
