@@ -25,9 +25,11 @@ import {
   NumberFormats,
   ValueFormatter,
   getValueFormatter,
+  tooltipHtml,
 } from '@superset-ui/core';
-import { TreemapSeriesNodeItemOption } from 'echarts/types/src/chart/treemap/TreemapSeries';
-import { EChartsCoreOption, TreemapSeriesOption } from 'echarts';
+import type { TreemapSeriesNodeItemOption } from 'echarts/types/src/chart/treemap/TreemapSeries';
+import type { EChartsCoreOption } from 'echarts/core';
+import type { TreemapSeriesOption } from 'echarts/charts';
 import {
   DEFAULT_FORM_DATA as DEFAULT_TREEMAP_FORM_DATA,
   EchartsTreemapChartProps,
@@ -96,14 +98,11 @@ export function formatTooltip({
       : 0;
     formattedPercent = percentFormatter(percent);
   }
-
-  // groupby1/groupby2/...
-  // metric: value (percent of parent)
-  return [
-    `<div>${treePath.join(' ▸ ')}</div>`,
-    `${metricLabel}: ${formattedValue}`,
-    formattedPercent ? ` (${formattedPercent})` : '',
-  ].join('');
+  const row = [metricLabel, formattedValue];
+  if (formattedPercent) {
+    row.push(formattedPercent);
+  }
+  return tooltipHtml([row], treePath.join(' ▸ '));
 }
 
 export default function transformProps(
@@ -185,7 +184,7 @@ export default function transformProps(
           colorSaturation: COLOR_SATURATION,
           itemStyle: {
             borderColor: BORDER_COLOR,
-            color: colorFn(name, sliceId),
+            color: colorFn(name, sliceId, colorScheme),
             borderWidth: BORDER_WIDTH,
             gapWidth: GAP_WIDTH,
           },
@@ -218,7 +217,7 @@ export default function transformProps(
       colorSaturation: COLOR_SATURATION,
       itemStyle: {
         borderColor: BORDER_COLOR,
-        color: colorFn(`${metricLabel}`, sliceId),
+        color: colorFn(`${metricLabel}`, sliceId, colorScheme),
         borderWidth: BORDER_WIDTH,
         gapWidth: GAP_WIDTH,
       },
