@@ -104,7 +104,7 @@ describe('chart actions', () => {
     waitForAsyncDataStub.restore();
 
     global.featureFlags = {
-      [FeatureFlag.GLOBAL_ASYNC_QUERIES]: false,
+      [FeatureFlag.GlobalAsyncQueries]: false,
     };
   });
 
@@ -157,7 +157,7 @@ describe('chart actions', () => {
 
     it('handleChartDataResponse should handle responses when GlobalAsyncQueries flag is enabled and results are returned synchronously', async () => {
       global.featureFlags = {
-        [FeatureFlag.GLOBAL_ASYNC_QUERIES]: true,
+        [FeatureFlag.GlobalAsyncQueries]: true,
       };
       const result = await handleChartDataResponse(
         { status: 200 },
@@ -168,7 +168,7 @@ describe('chart actions', () => {
 
     it('handleChartDataResponse should handle responses when GlobalAsyncQueries flag is enabled and query is running asynchronously', async () => {
       global.featureFlags = {
-        [FeatureFlag.GLOBAL_ASYNC_QUERIES]: true,
+        [FeatureFlag.GlobalAsyncQueries]: true,
       };
       const result = await handleChartDataResponse(
         { status: 202 },
