@@ -16,10 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React from 'react';
-import { t } from '@superset-ui/core';
+import { ReactNode } from 'react';
+import { ErrorSource, t, SupersetError } from '@superset-ui/core';
 import getErrorMessageComponentRegistry from './getErrorMessageComponentRegistry';
-import { SupersetError, ErrorSource } from './types';
 import ErrorAlert from './ErrorAlert';
 
 const DEFAULT_TITLE = t('Unexpected error');
@@ -28,13 +27,13 @@ type Props = {
   title?: string;
   error?: SupersetError;
   link?: string;
-  subtitle?: React.ReactNode;
+  subtitle?: ReactNode;
   copyText?: string;
   stackTrace?: string;
   source?: ErrorSource;
   description?: string;
   errorMitigationFunction?: () => void;
-  fallback?: React.ReactNode;
+  fallback?: ReactNode;
 };
 
 export default function ErrorMessageWithStackTrace({
