@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React from 'react';
+import { Key } from 'react';
 import cx from 'classnames';
 import { styled, useTheme } from '@superset-ui/core';
 import { AntdDropdown } from 'src/components';
@@ -29,7 +29,7 @@ export interface OptionProps {
   className?: string;
 }
 
-export type OnChangeHandler = (key: React.Key) => void;
+export type OnChangeHandler = (key: Key) => void;
 export type RenderElementHandler = (option: OptionProps) => JSX.Element;
 
 export interface PopoverDropdownProps {
@@ -42,7 +42,7 @@ export interface PopoverDropdownProps {
 }
 
 interface HandleSelectProps {
-  key: React.Key;
+  key: Key;
 }
 
 const MenuItem = styled(Menu.Item)`
