@@ -16,8 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import React from 'react';
-import { useArgs } from '@storybook/client-api';
+import { useArgs } from '@storybook/preview-api';
 import { Switch, SwitchProps } from '.';
 
 export default {
@@ -45,6 +44,7 @@ InteractiveSwitch.args = {
 InteractiveSwitch.argTypes = {
   size: {
     defaultValue: 'default',
-    control: { type: 'radio', options: ['small', 'default'] },
+    control: { type: 'radio' },
+    options: ['small', 'default'],
   },
 };
