@@ -18,14 +18,13 @@
  */
 // ParentSize uses resize observer so the dashboard will update size
 // when its container size changes, due to e.g., builder side panel opening
-import React, { FC, useCallback, useEffect, useMemo, useRef } from 'react';
+import { FC, useEffect, useMemo, useRef } from 'react';
 import { useDispatch, useSelector } from 'react-redux';
 import {
   Filter,
   Filters,
-  getCategoricalSchemeRegistry,
-  SupersetClient,
-  useComponentDidUpdate,
+  LabelsColorMapSource,
+  getLabelsColorMap,
 } from '@superset-ui/core';
 import { ParentSize } from '@visx/responsive';
 import { pick } from 'lodash';
@@ -44,9 +43,12 @@ import {
 import { getChartIdsInFilterScope } from 'src/dashboard/util/getChartIdsInFilterScope';
 import findTabIndexByComponentId from 'src/dashboard/util/findTabIndexByComponentId';
 import { setInScopeStatusOfFilters } from 'src/dashboard/actions/nativeFilters';
-import { dashboardInfoChanged } from 'src/dashboard/actions/dashboardInfo';
-import { setColorScheme } from 'src/dashboard/actions/dashboardState';
-import jsonStringify from 'json-stringify-pretty-compact';
+import { updateDashboardLabelsColor } from 'src/dashboard/actions/dashboardState';
+import {
+  applyColors,
+  getColorNamespace,
+  resetColors,
+} from 'src/utils/colorScheme';
 import { NATIVE_FILTER_DIVIDER_PREFIX } from '../nativeFilters/FiltersConfigModal/utils';
 import { findTabsWithChartsInScope } from '../nativeFilters/utils';
 import { getRootLevelTabsComponent } from './utils';
@@ -131,90 +133,35 @@ const DashboardContainer: FC<DashboardContainerProps> = ({ topLevelTabs }) => {
     dispatch(setInScopeStatusOfFilters(scopes));
   }, [nativeFilterScopes, dashboardLayout, dispatch]);
 
-  const verifyUpdateColorScheme = useCallback(() => {
-    const currentMetadata = dashboardInfo.metadata;
-    if (currentMetadata?.color_scheme) {
-      const metadata = { ...currentMetadata };
-      const colorScheme = metadata?.color_scheme;
-      const colorSchemeDomain = metadata?.color_scheme_domain || [];
-      const categoricalSchemes = getCategoricalSchemeRegistry();
-      const registryColorScheme =
-        categoricalSchemes.get(colorScheme, true) || undefined;
-      const registryColorSchemeDomain = registryColorScheme?.colors || [];
-      const defaultColorScheme = categoricalSchemes.defaultKey;
-      const colorSchemeExists = !!registryColorScheme;
-
-      const updateDashboardData = () => {
-        SupersetClient.put({
-          endpoint: `/api/v1/dashboard/${dashboardInfo.id}`,
-          headers: { 'Content-Type': 'application/json' },
-          body: JSON.stringify({
-            json_metadata: jsonStringify(metadata),
-          }),
-        }).catch(e => console.log(e));
-      };
-      const updateColorScheme = (scheme: string) => {
-        dispatch(setColorScheme(scheme));
-      };
-      const updateDashboard = () => {
-        dispatch(
-          dashboardInfoChanged({
-            metadata,
-          }),
-        );
-        updateDashboardData();
-      };
-      // selected color scheme does not exist anymore
-      // must fallback to the available default one
-      if (!colorSchemeExists) {
-        const updatedScheme =
-          defaultColorScheme?.toString() || 'supersetColors';
-        metadata.color_scheme = updatedScheme;
-        metadata.color_scheme_domain =
-          categoricalSchemes.get(defaultColorScheme)?.colors || [];
-
-        // reset shared_label_colors
-        // TODO: Requires regenerating the shared_label_colors after
-        // fixing a bug which affects their generation on dashboards with tabs
-        metadata.shared_label_colors = {};
-
-        updateColorScheme(updatedScheme);
-        updateDashboard();
-      } else {
-        // if this dashboard does not have a color_scheme_domain saved
-        // must create one and store it for the first time
-        if (colorSchemeExists && !colorSchemeDomain.length) {
-          metadata.color_scheme_domain = registryColorSchemeDomain;
-          updateDashboard();
-        }
-        // if the color_scheme_domain is not the same as the registry domain
-        // must update the existing color_scheme_domain
-        if (
-          colorSchemeExists &&
-          colorSchemeDomain.length &&
-          registryColorSchemeDomain.toString() !== colorSchemeDomain.toString()
-        ) {
-          metadata.color_scheme_domain = registryColorSchemeDomain;
-
-          // reset shared_label_colors
-          // TODO: Requires regenerating the shared_label_colors after
-          // fixing a bug which affects their generation on dashboards with tabs
-          metadata.shared_label_colors = {};
-
-          updateColorScheme(colorScheme);
-          updateDashboard();
-        }
-      }
-    }
-  }, [chartIds]);
-
-  useComponentDidUpdate(verifyUpdateColorScheme);
-
   const childIds: string[] = topLevelTabs
     ? topLevelTabs.children
     : [DASHBOARD_GRID_ID];
   const min = Math.min(tabIndex, childIds.length - 1);
   const activeKey = min === 0 ? DASHBOARD_GRID_ID : min.toString();
+  const TOP_OF_PAGE_RANGE = 220;
+
+  useEffect(() => {
+    // verify freshness of color map on tab change
+    // and when loading for first time
+    setTimeout(() => {
+      dispatch(updateDashboardLabelsColor());
+    }, 500);
+  }, [directPathToChild, dispatch]);
+
+  useEffect(() => {
+    const labelsColorMap = getLabelsColorMap();
+    const colorNamespace = getColorNamespace(
+      dashboardInfo?.metadata?.color_namespace,
+    );
+    labelsColorMap.source = LabelsColorMapSource.Dashboard;
+    // apply labels color as dictated by stored metadata
+    applyColors(dashboardInfo.metadata);
+
+    return () => {
+      resetColors(getColorNamespace(colorNamespace));
+    };
+    // eslint-disable-next-line react-hooks/exhaustive-deps
+  }, [dashboardInfo.id, dispatch]);
 
   return (
     <div className="grid-container" data-test="grid-container">
@@ -233,6 +180,18 @@ const DashboardContainer: FC<DashboardContainerProps> = ({ topLevelTabs }) => {
             fullWidth={false}
             animated={false}
             allowOverflow
+            onFocus={e => {
+              if (
+                // prevent scrolling when tabbing to the tab pane
+                e.target.classList.contains('ant-tabs-tabpane') &&
+                window.scrollY < TOP_OF_PAGE_RANGE
+              ) {
+                // prevent window from jumping down when tabbing
+                // if already at the top of the page
+                // to help with accessibility when using keyboard navigation
+                window.scrollTo(window.scrollX, 0);
+              }
+            }}
           >
             {childIds.map((id, index) => (
               // Matching the key of the first TabPane irrespective of topLevelTabs
