@@ -496,6 +496,7 @@ class Header extends PureComponent {
     const refreshWarning =
       dashboardInfo.common?.conf
         ?.SUPERSET_DASHBOARD_PERIODICAL_REFRESH_WARNING_MESSAGE;
+    const isEmbedded = !dashboardInfo?.userId;
 
     const handleOnPropertiesChange = updates => {
       const { dashboardInfoChanged, dashboardTitleChanged } = this.props;
@@ -553,7 +554,7 @@ class Header extends PureComponent {
                 visible={!editMode}
               />
             ),
-            !editMode && (
+            !editMode && !isEmbedded && (
               <MetadataBar
                 items={this.getMetadataItems()}
                 tooltipPlacement="bottom"
