@@ -16,18 +16,18 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import { FormInstance } from 'src/components';
-import shortid from 'shortid';
-import { getInitialDataMask } from 'src/dataMask/reducer';
 import {
+  Divider,
   Filter,
   FilterConfiguration,
-  NativeFilterType,
-  Divider,
   NativeFilterTarget,
+  NativeFilterType,
   logging,
 } from '@superset-ui/core';
+import { nanoid } from 'nanoid';
+import { FormInstance } from 'src/components';
 import { DASHBOARD_ROOT_ID } from 'src/dashboard/util/constants';
+import { getInitialDataMask } from 'src/dataMask/reducer';
 import { FilterRemoval, NativeFiltersForm } from './types';
 
 export const REMOVAL_DELAY_SECS = 5;
@@ -197,7 +197,7 @@ export const generateFilterId = (type: NativeFilterType) => {
     type === NativeFilterType.NativeFilter
       ? NATIVE_FILTER_PREFIX
       : NATIVE_FILTER_DIVIDER_PREFIX;
-  return `${prefix}${shortid.generate()}`;
+  return `${prefix}${nanoid()}`;
 };
 
 export const getFilterIds = (config: FilterConfiguration) =>
