@@ -16,11 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import { useTheme } from '@superset-ui/core';
+import { Filter, useTheme } from '@superset-ui/core';
 import { useSelector } from 'react-redux';
 
 import { getChartIdsInFilterScope } from 'src/dashboard/util/activeDashboardFilters';
 import { DashboardState, RootState } from 'src/dashboard/types';
+import { getRelatedCharts } from './getRelatedCharts';
 
 const selectFocusedFilterScope = (
   dashboardState: DashboardState,
@@ -41,6 +42,7 @@ const useFilterFocusHighlightStyles = (chartId: number) => {
   const dashboardState = useSelector(
     (state: RootState) => state.dashboardState,
   );
+
   const dashboardFilters = useSelector(
     (state: RootState) => state.dashboardFilters,
   );
@@ -49,6 +51,15 @@ const useFilterFocusHighlightStyles = (chartId: number) => {
     dashboardFilters,
   );
 
+  const slices =
+    useSelector((state: RootState) => state.sliceEntities.slices) || {};
+
+  const relatedCharts = getRelatedCharts(
+    nativeFilters.filters as Record<string, Filter>,
+    null,
+    slices,
+  );
+
   const highlightedFilterId =
     nativeFilters?.focusedFilterId || nativeFilters?.hoveredFilterId;
   if (!(focusedFilterScope || highlightedFilterId)) {
@@ -69,11 +80,7 @@ const useFilterFocusHighlightStyles = (chartId: number) => {
   };
 
   if (highlightedFilterId) {
-    if (
-      nativeFilters.filters[highlightedFilterId]?.chartsInScope?.includes(
-        chartId,
-      )
-    ) {
+    if (relatedCharts[highlightedFilterId]?.includes(chartId)) {
       return focusedChartStyles;
     }
   } else if (
