@@ -16,8 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-/* eslint-disable no-unused-expressions */
-import React from 'react';
 import sinon from 'sinon';
 import { shallow } from 'enzyme';
 import { FormItem } from 'src/components/Form';
