@@ -46,7 +46,14 @@ export interface ReportObject {
   name: string;
   owners: number[];
   recipients: [
-    { recipient_config_json: { target: string }; type: ReportRecipientType },
+    {
+      recipient_config_json: {
+        target: string;
+        ccTarget: string;
+        bccTarget: string;
+      };
+      type: ReportRecipientType;
+    },
   ];
   report_format: string;
   timezone: string;
