@@ -15,11 +15,11 @@
 # specific language governing permissions and limitations
 # under the License.
 import logging
+from functools import partial
 from typing import Any, Optional
 
 from flask_appbuilder.models.sqla import Model
 from marshmallow import ValidationError
-from sqlalchemy.exc import SQLAlchemyError
 
 from superset.commands.base import BaseCommand, CreateMixin
 from superset.commands.dataset.exceptions import (
@@ -31,9 +31,10 @@ from superset.commands.dataset.exceptions import (
     TableNotFoundValidationError,
 )
 from superset.daos.dataset import DatasetDAO
-from superset.daos.exceptions import DAOCreateFailedError
 from superset.exceptions import SupersetSecurityException
-from superset.extensions import db, security_manager
+from superset.extensions import security_manager
+from superset.sql_parse import Table
+from superset.utils.decorators import on_error, transaction
 
 logger = logging.getLogger(__name__)
 
@@ -42,53 +43,54 @@ class CreateDatasetCommand(CreateMixin, BaseCommand):
     def __init__(self, data: dict[str, Any]):
         self._properties = data.copy()
 
+    @transaction(on_error=partial(on_error, reraise=DatasetCreateFailedError))
     def run(self) -> Model:
         self.validate()
-        try:
-            # Creates SqlaTable (Dataset)
-            dataset = DatasetDAO.create(attributes=self._properties, commit=False)
 
-            # Updates columns and metrics from the dataset
-            dataset.fetch_metadata(commit=False)
-            db.session.commit()
-        except (SQLAlchemyError, DAOCreateFailedError) as ex:
-            logger.warning(ex, exc_info=True)
-            db.session.rollback()
-            raise DatasetCreateFailedError() from ex
+        dataset = DatasetDAO.create(attributes=self._properties)
+        dataset.fetch_metadata()
         return dataset
 
     def validate(self) -> None:
         exceptions: list[ValidationError] = []
         database_id = self._properties["database"]
+        catalog = self._properties.get("catalog")
+        schema = self._properties.get("schema")
         table_name = self._properties["table_name"]
-        schema = self._properties.get("schema", None)
-        sql = self._properties.get("sql", None)
+        sql = self._properties.get("sql")
         owner_ids: Optional[list[int]] = self._properties.get("owners")
 
-        # Validate uniqueness
-        if not DatasetDAO.validate_uniqueness(database_id, schema, table_name):
-            exceptions.append(DatasetExistsValidationError(table_name))
-
         # Validate/Populate database
         database = DatasetDAO.get_database_by_id(database_id)
         if not database:
             exceptions.append(DatabaseNotFoundValidationError())
         self._properties["database"] = database
 
+        # Validate uniqueness
+        if database:
+            if not catalog:
+                catalog = self._properties["catalog"] = database.get_default_catalog()
+
+            table = Table(table_name, schema, catalog)
+
+            if not DatasetDAO.validate_uniqueness(database, table):
+                exceptions.append(DatasetExistsValidationError(table))
+
         # Validate table exists on dataset if sql is not provided
         # This should be validated when the dataset is physical
         if (
             database
             and not sql
-            and not DatasetDAO.validate_table_exists(database, table_name, schema)
+            and not DatasetDAO.validate_table_exists(database, table)
         ):
-            exceptions.append(TableNotFoundValidationError(table_name))
+            exceptions.append(TableNotFoundValidationError(table))
 
         if sql:
             try:
                 security_manager.raise_for_access(
                     database=database,
                     sql=sql,
+                    catalog=catalog,
                     schema=schema,
                 )
             except SupersetSecurityException as ex:
