@@ -26,8 +26,8 @@ Create Date: 2019-10-09 15:05:06.965042
 revision = "cca2f5d568c8"
 down_revision = "b6fa807eac07"
 
-import sqlalchemy as sa
-from alembic import op
+import sqlalchemy as sa  # noqa: E402
+from alembic import op  # noqa: E402
 
 
 def upgrade():
