@@ -15,8 +15,9 @@
 # specific language governing permissions and limitations
 # under the License.
 
+from __future__ import annotations
+
 import re
-from typing import Optional
 
 from pgsanity.pgsanity import check_string
 
@@ -31,7 +32,11 @@ class PostgreSQLValidator(BaseSQLValidator):  # pylint: disable=too-few-public-m
 
     @classmethod
     def validate(
-        cls, sql: str, schema: Optional[str], database: Database
+        cls,
+        sql: str,
+        catalog: str | None,
+        schema: str | None,
+        database: Database,
     ) -> list[SQLValidationAnnotation]:
         annotations: list[SQLValidationAnnotation] = []
         valid, error = check_string(sql, add_semicolon=True)
