@@ -132,17 +132,13 @@ class TemporaryCacheRestApi(BaseSupersetApi, ABC):
             return self.response(404, message=str(ex))
 
     @abstractmethod
-    def get_create_command(self) -> Any:
-        ...
+    def get_create_command(self) -> Any: ...
 
     @abstractmethod
-    def get_update_command(self) -> Any:
-        ...
+    def get_update_command(self) -> Any: ...
 
     @abstractmethod
-    def get_get_command(self) -> Any:
-        ...
+    def get_get_command(self) -> Any: ...
 
     @abstractmethod
-    def get_delete_command(self) -> Any:
-        ...
+    def get_delete_command(self) -> Any: ...
