@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """Unit tests for Superset"""
-import json
+
 from contextlib import contextmanager
 from datetime import datetime, timedelta
 from unittest import mock
@@ -26,17 +26,27 @@ import pytest
 from superset import app, db
 from superset.commands.dataset.exceptions import DatasetNotFoundError
 from superset.common.utils.query_cache_manager import QueryCacheManager
-from superset.connectors.sqla.models import SqlaTable, SqlMetric, TableColumn
+from superset.connectors.sqla.models import (  # noqa: F401
+    SqlaTable,
+    SqlMetric,
+    TableColumn,
+)
 from superset.constants import CacheRegion
 from superset.daos.exceptions import DatasourceNotFound, DatasourceTypeNotSupportedError
 from superset.exceptions import SupersetGenericDBErrorException
 from superset.models.core import Database
-from superset.utils.core import backend, get_example_default_schema
-from superset.utils.database import get_example_database, get_main_database
+from superset.utils import json
+from superset.utils.core import backend, get_example_default_schema  # noqa: F401
+from superset.utils.database import (  # noqa: F401
+    get_example_database,
+    get_main_database,
+)
 from tests.integration_tests.base_tests import db_insert_temp_object, SupersetTestCase
+from tests.integration_tests.conftest import with_feature_flags
+from tests.integration_tests.constants import ADMIN_USERNAME
 from tests.integration_tests.fixtures.birth_names_dashboard import (
-    load_birth_names_dashboard_with_slices,
-    load_birth_names_data,
+    load_birth_names_dashboard_with_slices,  # noqa: F401
+    load_birth_names_data,  # noqa: F401
 )
 from tests.integration_tests.fixtures.datasource import get_datasource_post
 
@@ -46,7 +56,7 @@ def create_test_table_context(database: Database):
     schema = get_example_default_schema()
     full_table_name = f"{schema}.test_table" if schema else "test_table"
 
-    with database.get_sqla_engine_with_context() as engine:
+    with database.get_sqla_engine() as engine:
         engine.execute(
             f"CREATE TABLE IF NOT EXISTS {full_table_name} AS SELECT 1 as first, 2 as second"
         )
@@ -55,7 +65,7 @@ def create_test_table_context(database: Database):
 
     yield db.session
 
-    with database.get_sqla_engine_with_context() as engine:
+    with database.get_sqla_engine() as engine:
         engine.execute(f"DROP TABLE {full_table_name}")
 
 
@@ -65,10 +75,11 @@ class TestDatasource(SupersetTestCase):
 
     def tearDown(self):
         db.session.rollback()
+        super().tearDown()
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_external_metadata_for_physical_table(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         tbl = self.get_table(name="birth_names")
         url = f"/datasource/external_metadata/table/{tbl.id}/"
         resp = self.get_json_resp(url)
@@ -78,10 +89,9 @@ class TestDatasource(SupersetTestCase):
         )
 
     def test_always_filter_main_dttm(self):
-        self.login(username="admin")
         database = get_example_database()
 
-        sql = f"SELECT DATE() as default_dttm, DATE() as additional_dttm, 1 as metric;"
+        sql = f"SELECT DATE() as default_dttm, DATE() as additional_dttm, 1 as metric;"  # noqa: F541
         if database.backend == "sqlite":
             pass
         elif database.backend in ["postgresql", "mysql"]:
@@ -129,7 +139,7 @@ class TestDatasource(SupersetTestCase):
         db.session.commit()
 
     def test_external_metadata_for_virtual_table(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         table = SqlaTable(
             table_name="dummy_sql_table",
             database=get_example_database(),
@@ -148,7 +158,7 @@ class TestDatasource(SupersetTestCase):
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_external_metadata_by_name_for_physical_table(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         tbl = self.get_table(name="birth_names")
         params = prison.dumps(
             {
@@ -168,7 +178,7 @@ class TestDatasource(SupersetTestCase):
         )
 
     def test_external_metadata_by_name_for_virtual_table(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         table = SqlaTable(
             table_name="dummy_sql_table",
             database=get_example_database(),
@@ -196,7 +206,7 @@ class TestDatasource(SupersetTestCase):
         db.session.commit()
 
     def test_external_metadata_by_name_from_sqla_inspector(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         example_database = get_example_database()
         with create_test_table_context(example_database):
             params = prison.dumps(
@@ -261,7 +271,7 @@ class TestDatasource(SupersetTestCase):
         self.assertIn("error", resp)
 
     def test_external_metadata_for_virtual_table_template_params(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         table = SqlaTable(
             table_name="dummy_sql_table_with_template_params",
             database=get_example_database(),
@@ -280,7 +290,7 @@ class TestDatasource(SupersetTestCase):
         db.session.commit()
 
     def test_external_metadata_for_malicious_virtual_table(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         table = SqlaTable(
             table_name="malicious_sql_table",
             database=get_example_database(),
@@ -293,7 +303,7 @@ class TestDatasource(SupersetTestCase):
             self.assertEqual(resp["error"], "Only `SELECT` statements are allowed")
 
     def test_external_metadata_for_multistatement_virtual_table(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         table = SqlaTable(
             table_name="multistatement_sql_table",
             database=get_example_database(),
@@ -309,7 +319,7 @@ class TestDatasource(SupersetTestCase):
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     @mock.patch("superset.connectors.sqla.models.SqlaTable.external_metadata")
     def test_external_metadata_error_return_400(self, mock_get_datasource):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         tbl = self.get_table(name="birth_names")
         url = f"/datasource/external_metadata/table/{tbl.id}/"
 
@@ -335,7 +345,7 @@ class TestDatasource(SupersetTestCase):
                     self.assertEqual(obj1.get(k), obj2.get(k))
 
     def test_save(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         tbl_id = self.get_table(name="birth_names").id
 
         datasource_post = get_datasource_post()
@@ -353,11 +363,10 @@ class TestDatasource(SupersetTestCase):
             elif k == "owners":
                 self.assertEqual([o["id"] for o in resp[k]], datasource_post["owners"])
             else:
-                print(k)
                 self.assertEqual(resp[k], datasource_post[k])
 
     def test_save_default_endpoint_validation_success(self):
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         tbl_id = self.get_table(name="birth_names").id
 
         datasource_post = get_datasource_post()
@@ -375,9 +384,8 @@ class TestDatasource(SupersetTestCase):
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_change_database(self):
-        self.login(username="admin")
         admin_user = self.get_user("admin")
-
+        self.login(admin_user.username)
         tbl = self.get_table(name="birth_names")
         tbl_id = tbl.id
         db_id = tbl.database_id
@@ -397,8 +405,8 @@ class TestDatasource(SupersetTestCase):
         self.delete_fake_db()
 
     def test_save_duplicate_key(self):
-        self.login(username="admin")
         admin_user = self.get_user("admin")
+        self.login(admin_user.username)
         tbl_id = self.get_table(name="birth_names").id
 
         datasource_post = get_datasource_post()
@@ -427,8 +435,8 @@ class TestDatasource(SupersetTestCase):
         self.assertIn("Duplicate column name(s): <new column>", resp["error"])
 
     def test_get_datasource(self):
-        self.login(username="admin")
         admin_user = self.get_user("admin")
+        self.login(admin_user.username)
         tbl = self.get_table(name="birth_names")
 
         datasource_post = get_datasource_post()
@@ -459,7 +467,7 @@ class TestDatasource(SupersetTestCase):
             return "Warning message!"
 
         app.config["DATASET_HEALTH_CHECK"] = my_check
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         tbl = self.get_table(name="birth_names")
         datasource = db.session.query(SqlaTable).filter_by(id=tbl.id).one_or_none()
         assert datasource.health_check_message == "Warning message!"
@@ -473,7 +481,7 @@ class TestDatasource(SupersetTestCase):
             lambda: DatasourceDAO.get_datasource("table", 9999999),
         )
 
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         resp = self.get_json_resp("/datasource/get/table/500000/", raise_on_error=False)
         self.assertEqual(resp.get("error"), "Datasource does not exist")
 
@@ -485,7 +493,7 @@ class TestDatasource(SupersetTestCase):
             lambda: DatasourceDAO.get_datasource("druid", 9999999),
         )
 
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
         resp = self.get_json_resp("/datasource/get/druid/500000/", raise_on_error=False)
         self.assertEqual(resp.get("error"), "'druid' is not a valid DatasourceType")
 
@@ -529,10 +537,12 @@ def test_get_samples(test_client, login_as_admin, virtual_dataset):
     assert "coltypes" in rv2.json["result"]
     assert "data" in rv2.json["result"]
 
-    eager_samples = virtual_dataset.database.get_df(
-        f"select * from ({virtual_dataset.sql}) as tbl"
-        f' limit {app.config["SAMPLES_ROW_LIMIT"]}'
+    sql = (
+        f"select * from ({virtual_dataset.sql}) as tbl "
+        f'limit {app.config["SAMPLES_ROW_LIMIT"]}'
     )
+    eager_samples = virtual_dataset.database.get_df(sql)
+
     # the col3 is Decimal
     eager_samples["col3"] = eager_samples["col3"].apply(float)
     eager_samples = eager_samples.to_dict(orient="records")
@@ -558,6 +568,7 @@ def test_get_samples_with_incorrect_cc(test_client, login_as_admin, virtual_data
         assert "INCORRECT SQL" in rv.json.get("error")
 
 
+@with_feature_flags(ALLOW_ADHOC_SUBQUERY=True)
 def test_get_samples_on_physical_dataset(test_client, login_as_admin, physical_dataset):
     uri = (
         f"/datasource/samples?datasource_id={physical_dataset.id}&datasource_type=table"
@@ -622,6 +633,7 @@ def test_get_samples_with_filters(test_client, login_as_admin, virtual_dataset):
     assert rv.json["result"]["rowcount"] == 0
 
 
+@with_feature_flags(ALLOW_ADHOC_SUBQUERY=True)
 def test_get_samples_with_time_filter(test_client, login_as_admin, physical_dataset):
     uri = (
         f"/datasource/samples?datasource_id={physical_dataset.id}&datasource_type=table"
@@ -642,6 +654,7 @@ def test_get_samples_with_time_filter(test_client, login_as_admin, physical_data
     assert rv.json["result"]["total_count"] == 2
 
 
+@with_feature_flags(ALLOW_ADHOC_SUBQUERY=True)
 def test_get_samples_with_multiple_filters(
     test_client, login_as_admin, physical_dataset
 ):
