@@ -16,7 +16,7 @@
 # under the License.
 # isort:skip_file
 """Unit tests for Sql Lab"""
-import json
+
 from datetime import datetime
 from textwrap import dedent
 
@@ -28,7 +28,7 @@ import prison
 
 from freezegun import freeze_time
 from superset import db, security_manager
-from superset.connectors.sqla.models import SqlaTable
+from superset.connectors.sqla.models import SqlaTable  # noqa: F401
 from superset.db_engine_specs import BaseEngineSpec
 from superset.db_engine_specs.hive import HiveEngineSpec
 from superset.db_engine_specs.presto import PrestoEngineSpec
@@ -43,19 +43,24 @@ from superset.sql_lab import (
     apply_limit_if_exists,
 )
 from superset.sql_parse import CtasMethod
-from superset.utils.core import (
-    backend,
-    datetime_to_epoch,
-)
+from superset.utils.core import backend
+from superset.utils import json
+from superset.utils.json import datetime_to_epoch  # noqa: F401
 from superset.utils.database import get_example_database, get_main_database
 
-from .base_tests import SupersetTestCase
-from .conftest import CTAS_SCHEMA_NAME
-from tests.integration_tests.fixtures.birth_names_dashboard import (
-    load_birth_names_dashboard_with_slices,
-    load_birth_names_data,
+from tests.integration_tests.base_tests import SupersetTestCase
+from tests.integration_tests.conftest import CTAS_SCHEMA_NAME
+from tests.integration_tests.constants import (
+    ADMIN_USERNAME,
+    GAMMA_SQLLAB_NO_DATA_USERNAME,
+    GAMMA_SQLLAB_USERNAME,
+    GAMMA_USERNAME,
 )
-from tests.integration_tests.fixtures.users import create_gamma_sqllab_no_data
+from tests.integration_tests.fixtures.birth_names_dashboard import (
+    load_birth_names_dashboard_with_slices,  # noqa: F401
+    load_birth_names_data,  # noqa: F401
+)
+from tests.integration_tests.fixtures.users import create_gamma_sqllab_no_data  # noqa: F401
 
 QUERY_1 = "SELECT * FROM birth_names LIMIT 1"
 QUERY_2 = "SELECT * FROM NO_TABLE"
@@ -66,27 +71,24 @@ QUERY_3 = "SELECT * FROM birth_names LIMIT 10"
 class TestSqlLab(SupersetTestCase):
     """Testings for Sql Lab"""
 
-    @pytest.mark.usefixtures("load_birth_names_data")
     def run_some_queries(self):
         db.session.query(Query).delete()
-        db.session.commit()
         self.run_sql(QUERY_1, client_id="client_id_1", username="admin")
         self.run_sql(QUERY_2, client_id="client_id_2", username="admin")
         self.run_sql(QUERY_3, client_id="client_id_3", username="gamma_sqllab")
-        self.logout()
 
     def tearDown(self):
-        self.logout()
         db.session.query(Query).delete()
         db.session.commit()
         db.session.close()
+        super().tearDown()
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_sql_json(self):
         examples_db = get_example_database()
         engine_name = examples_db.db_engine_spec.engine_name
 
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
 
         data = self.run_sql("SELECT * FROM birth_names LIMIT 10", "1")
         self.assertLess(0, len(data["data"]))
@@ -129,13 +131,17 @@ class TestSqlLab(SupersetTestCase):
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_sql_json_dml_disallowed(self):
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
 
         data = self.run_sql("DELETE FROM birth_names", "1")
         assert data == {
             "errors": [
                 {
-                    "message": "Only SELECT statements are allowed against this database.",
+                    "message": (
+                        "This database does not allow for DDL/DML, and the query "
+                        "could not be parsed to confirm it is a read-only query. Please "
+                        "contact your administrator for more assistance."
+                    ),
                     "error_type": SupersetErrorType.DML_NOT_ALLOWED_ERROR,
                     "level": ErrorLevel.ERROR,
                     "extra": {
@@ -155,7 +161,7 @@ class TestSqlLab(SupersetTestCase):
         """
         SQLLab: Test SQLLab query execution info propagation to saved queries
         """
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
 
         sql_statement = "SELECT * FROM birth_names LIMIT 10"
         examples_db_id = get_example_database().id
@@ -164,7 +170,7 @@ class TestSqlLab(SupersetTestCase):
         db.session.commit()
 
         with freeze_time(datetime.now().isoformat(timespec="seconds")):
-            self.run_sql(sql_statement, "1", username="admin")
+            self.run_sql(sql_statement, "1")
             saved_query_ = (
                 db.session.query(SavedQuery)
                 .filter(
@@ -193,7 +199,7 @@ class TestSqlLab(SupersetTestCase):
             old_allow_ctas = examples_db.allow_ctas
             examples_db.allow_ctas = True  # enable cta
 
-            self.login("admin")
+            self.login(ADMIN_USERNAME)
             tmp_table_name = f"test_target_{ctas_method.lower()}"
             self.run_sql(
                 "SELECT * FROM birth_names",
@@ -207,12 +213,12 @@ class TestSqlLab(SupersetTestCase):
             # assertions
             db.session.commit()
             examples_db = get_example_database()
-            with examples_db.get_sqla_engine_with_context() as engine:
+            with examples_db.get_sqla_engine() as engine:
                 data = engine.execute(
                     f"SELECT * FROM admin_database.{tmp_table_name}"
                 ).fetchall()
                 names_count = engine.execute(
-                    f"SELECT COUNT(*) FROM birth_names"
+                    f"SELECT COUNT(*) FROM birth_names"  # noqa: F541
                 ).first()
                 self.assertEqual(
                     names_count[0], len(data)
@@ -225,7 +231,7 @@ class TestSqlLab(SupersetTestCase):
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_multi_sql(self):
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
 
         multi_sql = """
         SELECT * FROM birth_names LIMIT 1;
@@ -236,7 +242,7 @@ class TestSqlLab(SupersetTestCase):
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_explain(self):
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
 
         data = self.run_sql("EXPLAIN SELECT * FROM birth_names", "1")
         self.assertLess(0, len(data["data"]))
@@ -258,16 +264,14 @@ class TestSqlLab(SupersetTestCase):
         self.assertLess(0, len(data["data"]))
 
     def test_sqllab_has_access(self):
-        for username in ("admin", "gamma_sqllab"):
+        for username in (ADMIN_USERNAME, GAMMA_SQLLAB_USERNAME):
             self.login(username)
             for endpoint in ("/sqllab/", "/sqllab/history/"):
                 resp = self.client.get(endpoint)
                 self.assertEqual(200, resp.status_code)
 
-            self.logout()
-
     def test_sqllab_no_access(self):
-        self.login("gamma")
+        self.login(GAMMA_USERNAME)
         for endpoint in ("/sqllab/", "/sqllab/history/"):
             resp = self.client.get(endpoint)
             # Redirects to the main page
@@ -280,9 +284,15 @@ class TestSqlLab(SupersetTestCase):
             # sqlite doesn't support database creation
             return
 
+        catalog = examples_db.get_default_catalog()
         sqllab_test_db_schema_permission_view = (
             security_manager.add_permission_view_menu(
-                "schema_access", f"[{examples_db.name}].[{CTAS_SCHEMA_NAME}]"
+                "schema_access",
+                security_manager.get_schema_perm(
+                    examples_db.name,
+                    catalog,
+                    CTAS_SCHEMA_NAME,
+                ),
             )
         )
         schema_perm_role = security_manager.add_role("SchemaPermission")
@@ -293,7 +303,7 @@ class TestSqlLab(SupersetTestCase):
             "SchemaUser", ["SchemaPermission", "Gamma", "sql_lab"]
         )
 
-        with examples_db.get_sqla_engine_with_context() as engine:
+        with examples_db.get_sqla_engine() as engine:
             engine.execute(
                 f"CREATE TABLE IF NOT EXISTS {CTAS_SCHEMA_NAME}.test_table AS SELECT 1 as c1, 2 as c2"
             )
@@ -322,7 +332,7 @@ class TestSqlLab(SupersetTestCase):
             self.assertEqual(1, len(data["data"]))
 
         db.session.query(Query).delete()
-        with get_example_database().get_sqla_engine_with_context() as engine:
+        with get_example_database().get_sqla_engine() as engine:
             engine.execute(f"DROP TABLE IF EXISTS {CTAS_SCHEMA_NAME}.test_table")
         db.session.commit()
 
@@ -330,7 +340,7 @@ class TestSqlLab(SupersetTestCase):
         self.run_sql(
             "SELECT name as col, gender as col FROM birth_names LIMIT 10",
             client_id="2e2df3",
-            username="admin",
+            username=ADMIN_USERNAME,
             raise_on_error=True,
         )
 
@@ -360,7 +370,7 @@ class TestSqlLab(SupersetTestCase):
 
     @pytest.mark.usefixtures("load_birth_names_dashboard_with_slices")
     def test_sql_limit(self):
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
         test_limit = 1
         data = self.run_sql("SELECT * FROM birth_names", client_id="sql_limit_1")
         self.assertGreater(len(data["data"]), test_limit)
@@ -411,13 +421,14 @@ class TestSqlLab(SupersetTestCase):
         self.assertEqual(len(data["data"]), 1200)
         self.assertEqual(data["query"]["limitingFactor"], LimitingFactor.NOT_LIMITED)
 
+    @pytest.mark.usefixtures("load_birth_names_data")
     def test_query_api_filter(self) -> None:
         """
         Test query api without can_only_access_owned_queries perm added to
         Admin and make sure all queries show up.
         """
         self.run_some_queries()
-        self.login(username="admin")
+        self.login(ADMIN_USERNAME)
 
         url = "/api/v1/query/"
         data = self.get_json_resp(url)
@@ -430,6 +441,7 @@ class TestSqlLab(SupersetTestCase):
         assert admin.first_name in user_queries
         assert gamma_sqllab.first_name in user_queries
 
+    @pytest.mark.usefixtures("load_birth_names_data")
     def test_query_api_can_access_all_queries(self) -> None:
         """
         Test query api with can_access_all_queries perm added to
@@ -445,9 +457,8 @@ class TestSqlLab(SupersetTestCase):
         )
         db.session.commit()
 
-        # Test search_queries for Admin user
         self.run_some_queries()
-        self.login("gamma_sqllab")
+        self.login(GAMMA_SQLLAB_USERNAME)
         url = "/api/v1/query/"
         data = self.get_json_resp(url)
         self.assertEqual(3, len(data["result"]))
@@ -467,8 +478,7 @@ class TestSqlLab(SupersetTestCase):
         Test query api with sql_editor_id filter to
         gamma and make sure sql editor associated queries show up.
         """
-        username = "gamma_sqllab"
-        self.login("gamma_sqllab")
+        self.login(GAMMA_SQLLAB_USERNAME)
 
         # create a tab
         data = {
@@ -489,14 +499,12 @@ class TestSqlLab(SupersetTestCase):
         self.run_sql(
             "SELECT 1",
             "client_id_1",
-            username=username,
             raise_on_error=True,
             sql_editor_id=str(tab_state_id),
         )
         self.run_sql(
             "SELECT 2",
             "client_id_2",
-            username=username,
             raise_on_error=True,
             sql_editor_id=str(tab_state_id),
         )
@@ -504,7 +512,6 @@ class TestSqlLab(SupersetTestCase):
         self.run_sql(
             "SELECT 3",
             "client_id_3",
-            username=username,
             raise_on_error=True,
         )
 
@@ -519,21 +526,21 @@ class TestSqlLab(SupersetTestCase):
             {r.get("sql") for r in self.get_json_resp(url)["result"]},
         )
 
+    @pytest.mark.usefixtures("load_birth_names_data")
     def test_query_admin_can_access_all_queries(self) -> None:
         """
         Test query api with all_query_access perm added to
         Admin and make sure only Admin queries show up. This is the default
         """
-        # Test search_queries for Admin user
         self.run_some_queries()
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
 
         url = "/api/v1/query/"
         data = self.get_json_resp(url)
         self.assertEqual(3, len(data["result"]))
 
     def test_api_database(self):
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
         self.create_fake_db()
         get_example_database()
         get_main_database()
@@ -561,7 +568,7 @@ class TestSqlLab(SupersetTestCase):
         clear=True,
     )
     def test_sql_json_parameter_error(self):
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
 
         data = self.run_sql(
             "SELECT * FROM birth_names WHERE state = '{{ state }}' LIMIT 10",
@@ -601,7 +608,7 @@ class TestSqlLab(SupersetTestCase):
         clear=True,
     )
     def test_sql_json_parameter_authorized(self):
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
 
         data = self.run_sql(
             "SELECT name FROM {{ table }} LIMIT 10",
@@ -618,7 +625,7 @@ class TestSqlLab(SupersetTestCase):
         clear=True,
     )
     def test_sql_json_parameter_forbidden(self):
-        self.login("gamma_sqllab_no_data")
+        self.login(GAMMA_SQLLAB_NO_DATA_USERNAME)
 
         data = self.run_sql(
             "SELECT name FROM {{ table }} LIMIT 10",
@@ -647,7 +654,7 @@ class TestSqlLab(SupersetTestCase):
             SELECT /*+ hint */ @value AS foo;
         """
         )
-        mock_db = mock.MagicMock()
+        mock_db = mock.MagicMock()  # noqa: F841
         mock_query = mock.MagicMock()
         mock_query.database.allow_run_async = False
         mock_cursor = mock.MagicMock()
@@ -751,7 +758,7 @@ class TestSqlLab(SupersetTestCase):
             SELECT /*+ hint */ @value AS foo;
         """
         )
-        mock_db = mock.MagicMock()
+        mock_db = mock.MagicMock()  # noqa: F841
         mock_query = mock.MagicMock()
         mock_query.database.allow_run_async = False
         mock_cursor = mock.MagicMock()
@@ -862,7 +869,7 @@ class TestSqlLab(SupersetTestCase):
         if examples_db.backend == "sqlite":
             return
 
-        self.login("admin")
+        self.login(ADMIN_USERNAME)
 
         with mock.patch.object(
             examples_db.db_engine_spec, "handle_cursor"
