@@ -24,7 +24,7 @@ import numpy as np
 import pandas as pd
 import pytest
 
-import tests.integration_tests.test_app
+import tests.integration_tests.test_app  # noqa: F401
 import superset.viz as viz
 from superset import app
 from superset.constants import NULL_STRING
@@ -117,7 +117,7 @@ class TestBaseViz(SupersetTestCase):
         datasource.get_column = Mock(return_value=mock_dttm_col)
         mock_dttm_col.python_date_format = "epoch_ms"
         result = test_viz.get_df(query_obj)
-        import logging
+        import logging  # noqa: F401
 
         logger.info(result)
         pd.testing.assert_series_equal(
